@@ -1,10 +1,12 @@
 from neo.Utils.BlockchainFixtureTestCase import BlockchainFixtureTestCase
+from neo.Settings import settings
+import os
 
 
 class LevelDBBlockchainTest(BlockchainFixtureTestCase):
     @classmethod
     def leveldb_testpath(self):
-        return './fixtures/test_chain'
+        return os.path.join(settings.DATA_DIR_PATH, 'fixtures/test_chain')
 
     def test_01_initial_setup(self):
         self.assertEqual(self._blockchain.Height, 758715)
