@@ -3,16 +3,19 @@ from neo.Implementations.Blockchains.LevelDB.LevelDBBlockchain import LevelDBBlo
 import shutil
 import time
 from neo.Utils.NeoTestCase import NeoTestCase
+from neo.Settings import settings
+import os
 
 
 class VerifiableTestCase(NeoTestCase):
 
-    LEVELDB_TESTPATH = './fixtures/test_chain'
+    LEVELDB_TESTPATH = os.path.join(settings.DATA_DIR_PATH, 'fixtures/test_chain')
 
     _blockchain = None
 
     @classmethod
     def setUpClass(self):
+        os.makedirs(self.LEVELDB_TESTPATH, exist_ok=True)
         self._blockchain = LevelDBBlockchain(path=self.LEVELDB_TESTPATH)
         Blockchain.RegisterBlockchain(self._blockchain)
 
