@@ -11,6 +11,7 @@ from neo.VM.InteropService import Array, Struct, StackItem, CollectionMixin, Map
 from neocore.UInt160 import UInt160
 from neo.Settings import settings
 from neo.VM.VMFault import VMFault
+from logging import DEBUG as LOGGING_LEVEL_DEBUG
 
 
 class ExecutionEngine():
@@ -35,6 +36,7 @@ class ExecutionEngine():
     log_file_name = 'vm_instructions.log'
     # file descriptor
     log_file = None
+    _is_write_log = False
 
     def write_log(self, message):
         """
@@ -43,7 +45,7 @@ class ExecutionEngine():
         Args:
             message (str): string message to write to file.
         """
-        if settings.log_vm_instructions and self.log_file and not self.log_file.closed:
+        if self._is_write_log and self.log_file and not self.log_file.closed:
             self.log_file.write(message + '\n')
 
     @property
@@ -103,6 +105,7 @@ class ExecutionEngine():
         self._AltStack = RandomAccessStack(name='Alt')
         self._ExecutedScriptHashes = []
         self.ops_processed = 0
+        self._is_write_log = settings.log_vm_instructions
 
     def AddBreakPoint(self, position):
         self.CurrentContext.Breakpoints.add(position)
@@ -902,15 +905,11 @@ class ExecutionEngine():
         else:
             op = self.CurrentContext.OpReader.ReadByte(do_ord=False)
 
-#        opname = ToName(op)
-#        logger.info("____________________________________________________")
-#        logger.info("[%s] [%s] %02x -> %s" % (self.CurrentContext.InstructionPointer,self.ops_processed,int.from_bytes(op,byteorder='little'), opname))
-#        logger.info("-----------------------------------")
-
         self.ops_processed += 1
 
         try:
-            self.write_log("{} {}".format(self.ops_processed, ToName(op)))
+            if self._is_write_log:
+                self.write_log("{} {}".format(self.ops_processed, ToName(op)))
             self.ExecuteOp(op, self.CurrentContext)
         except Exception as e:
             error_msg = "COULD NOT EXECUTE OP (%s): %s %s %s" % (self.ops_processed, e, op, ToName(op))
@@ -948,6 +947,9 @@ class ExecutionEngine():
     def VM_FAULT_and_report(self, id, *args):
         self._VMState |= VMState.FAULT
 
+        if settings.log_level != LOGGING_LEVEL_DEBUG:
+            return
+
         if id == VMFault.INVALID_JUMP:
             error_msg = "Attemping to JMP/JMPIF/JMPIFNOT to an invalid location."
 
@@ -1016,7 +1018,6 @@ class ExecutionEngine():
         else:
             error_msg = id
 
-        # these get used a lot actually now, so we dont want them printed to the console
         if id in [VMFault.THROW, VMFault.THROWIFNOT]:
             logger.debug("({}) {}".format(self.ops_processed, id))
         else:
